% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/depth.fd.R
\name{depth.ABD}
\alias{depth.ABD}
\title{Adjusted band depth for functional data}
\usage{
depth.ABD(A, B, norm = c("C", "L2"), J = 2, K = 1)
}
\arguments{
\item{A}{Functions whose depth is computed, represented by a matrix of its functional values of 
size \code{m*d}. \code{m} stands for the number of functions, \code{d}
is the number equidistant points in the domain of the data at which the functional
values of the \code{m} functions are evaluated.}

\item{B}{Random sample functions with respect to which the depth of \code{A} is computed. 
\code{B} is represented by a matrix of 
size \code{n*d}, where \code{n} is the sample size, and \code{d}
is the number equidistant points in the domain of the data at which the functional
values of the \code{n} functions are evaluated. The grid of observation points for the 
functions \code{A} and \code{B} must be the same.}

\item{norm}{The norm used for the computation of the depth. Two possible 
choices are implemented: \code{C} for the uniform norm of continuous functions, 
and \code{L2} for the \eqn{L^2} norm of integrable functions.}

\item{J}{The order of the adjusted band depth, that is the maximal number of functions
taken in a band. Acceptable values are \code{2}, \code{3},... By default this value is set to \code{2}. 
Note that this is NOT the order as
defined in the order-extended version of adjusted band depths in Nagy et al. (2016), used
for the detection of shape outlying curves.}

\item{K}{Number of sub-samples of the functions from \code{B} taken to speed up the
computation. By default, sub-sampling is not performed. Values of \code{K} larger than \code{1}
result in an approximation of the adjusted band depth.}
}
\value{
A vectors of length \code{m} of the adjusted band depths.
}
\description{
The adjusted band depth 
of functional real-valued data based on either the
\eqn{C} (uniform) norm, or on the \eqn{L^2} norm of functions.
}
\details{
The function returns the vector of the sample adjusted band depth values. The kernel 
used in the evaluation is the function \eqn{K(u) = exp(-u)}.
}
\examples{
data(population)
A = as.matrix(population[1:20,1:66])
B = as.matrix(population[21:50,1:66])
depth.ABD(A,B)
depth.ABD(A,B,norm="L2")

}
\author{
Stanislav Nagy, \email{stanislav.nagy@kuleuven.be}
}
\references{
Gijbels, I., Nagy, S. (2015), Consistency of non-integrated depths for functional data,
\emph{J. Multivariate Anal.} \bold{140}, 259 - 282.

Nagy, S., Gijbels, I. and Hlubinka, D.  (2016), Depth-based recognition of shape outlying functions, \emph{Under review}.
}
\seealso{
\code{\link{depth.BD}}
}
\keyword{band}
\keyword{data}
\keyword{depth,}
\keyword{functional}

