% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/depth.fd.R
\name{depth.RP1}
\alias{depth.RP1}
\title{Univariate random projection depths for functional data}
\usage{
depth.RP1(A, B, nproj = 50, nproj2 = 5)
}
\arguments{
\item{A}{Functions whose depth is computed, represented by a matrix of its functional values of 
size \code{m*d}. \code{m} stands for the number of functions, \code{d}
is the number equidistant points in the domain of the data at which the functional
values of the \code{m} functions are evaluated.}

\item{B}{Random sample functions with respect to which the depth of \code{A} is computed. 
\code{B} is represented by a matrix of 
size \code{n*d}, where \code{n} is the sample size, and \code{d}
is the number equidistant points in the domain of the data at which the functional
values of the \code{n} functions are evaluated. The grid of observation points for the 
functions \code{A} and \code{B} must be the same.}

\item{nproj}{Number of projections taken in the computation of the random projection depth. By default taken
to be \code{51}.}

\item{nproj2}{Number of projections taken in the computation of the random functional depth. By default taken
to be \code{5}. \code{nproj2} should be much smaller than \code{d}, the dimensionality of the discretized 
functional data.}
}
\value{
Three vectors of depth values of length \code{m} are returned:
\itemize{
\item \code{Simpl_FD} the random projection depth based on the univariate simplicial depth,
\item \code{Half_FD} the random projection depth based on the univariate halfspace depth,
\item \code{RHalf_FD} the random halfspace depth.
}
}
\description{
Random projection depth and random functional depth for functional data.
}
\details{
The function returns the vectors of sample random projection, and random functional depth values. 
The random projection depth described in Cuevas et al. (2007) is based on the average univariate depth
of one-dimensional projections of functional data. The projections are taken randomly as a sample of standard
normal \code{d}-dimensional random variables, where \code{d} stands for the dimensionality of the discretized
functional data. 

The random functional depth (also called random Tukey depth, or random halfspace depth) is described in
Cuesta-Albertos and Nieto-Reyes (2008). The functional data are projected into the real line in random 
directions as for the random projection depths. Afterwards, an approximation of the halfspace (Tukey) depth
based on this limited number of univariate projections is assessed.
}
\examples{
data(population)
A = as.matrix(population[1:20,1:66])
B = as.matrix(population[21:50,1:66])
depth.RP1(A,B)

}
\author{
Stanislav Nagy, \email{stanislav.nagy@kuleuven.be}
}
\references{
Cuevas, A., Febrero, M. and Fraiman, R.  (2007), Robust estimation and classification for functional data via projection-based depth notions, 
\emph{Computational Statistics} \bold{22} (3), 481  496.

Cuesta-Albertos, J.A. and Nieto-Reyes, A. (2008), The random Tukey depth, 
\emph{Computational Statistics & Data Analysis} \bold{52} (11), 4979 - 4988.
}
\seealso{
\code{\link{depth.RP2}}
}
\keyword{Tukey}
\keyword{data}
\keyword{depth,}
\keyword{functional}
\keyword{projection}
\keyword{random}

