\name{depth.fd-package}
\alias{depth.fd-package}
\alias{depth.fd}
\docType{package}
\title{
\packageTitle{depth.fd}
}
\description{
\packageDescription{depth.fd}
}
\details{
Computation of various types of depth for both univariate (\eqn{R}-valued), and bivariate (\eqn{R^2}-valued) functional data. 
The depths designed for bivariate functional data may be used for the computation of depths of random functions
and their derivatives, incorporating the information about the shapes of the curves. For an overview of the depths
implemented in the package see the Supplementary Material provided with Nagy et al. (2016). 

For functional data whose values are observed contaminated with additive noise, preprocessing of the curves by means of fast kernel smoothing 
is available. For details see Nagy and Ferraty (2016). 

The historical population-by-country data example of functional data is provided.

The DESCRIPTION file:
\packageDESCRIPTION{depth.fd}
\packageIndices{depth.fd}
The package contains a variety of depths for functional data:
\itemize{
\item \code{depth.fd1} general order extended integrated and infimal depths for univariate functional data,
\item \code{depth.fd2} general order extended integrated and infimal depths for bivariate functional data, or univariate functional data with derivatives,
\item \code{depth.ABD} the adjusted band depth for functional data,
\item \code{depth.BD}  the band depth for functional data,
\item \code{depth.HR}  the half-region depth for functional data,
\item \code{depth.hM}  the h-mode depth based on both the uniform and the \eqn{L^2} norm for functional data,
\item \code{depth.hM2}  the h-mode depth based on the \eqn{L^2} norm for bivariate functional data, or univariate functional data with derivatives,
\item \code{depth.RP1}  the random projection depth for functional data,
\item \code{depth.RP2}  the double random projection depth for bivariate functional data, or univariate functional data with derivatives.
}
To process the functional observations, function \code{\link{FKS}} provides a fast implementation
of the kernel smoothing procedure. Function \code{\link{derivatives.est}} implements the estimation of derivatives of functional data.
\code{\link{shape.fd.analysis}} produces the first, and second order diagnostic plots, enabling the inference into the shape properties of
a function, see Nagy et al. (2016).  \code{\link{shape.fd.outliers}} performs informal shape outlier detection for functional data.

The world population data analysed in Nagy et al. (2016) is provided as the \code{\link{population2010}} dataset. 
A new revision of this data is available as the \code{\link{population}} dataset.
}
\author{
Stanislav Nagy

Maintainer: Stanislav Nagy, \email{stanislav.nagy@kuleuven.be}
}
\references{
Nagy, S., Gijbels, I. and Hlubinka, D. (2016), Depth-based recognition of shape outlying functions, \emph{Under review}.

Nagy, S. and Ferraty, F. (2016), Data depth for measurable noisy random functions, \emph{Under review}.}

\keyword{ functional data, data depth, derivatives, kernel smoothing, outlier detection }
\seealso{
\code{\link{FKS}}, \code{\link{depth.fd1}}, \code{\link{depth.fd2}}, \code{\link{depth.hM}}, \code{\link{depth.hM2}},
\code{\link{depth.ABD}}, \code{\link{depth.BD}}, \code{\link{depth.HR}}, \code{\link{depth.RP1}},
\code{\link{depth.RP2}}, \code{\link{shape.fd.analysis}}, \code{\link{shape.fd.outliers}}
}
\examples{
FKS(t<-runif(100),t^2+rnorm(100),seq(0,1,length=101))

data(population)
A = as.matrix(population[1:20,1:61])
B = as.matrix(population[21:50,1:61])

# order extended integrated and infimal depths
depth.fd1(A,B)
depth.fd1(A,B,order=2)
depth.fd1(A,B,order=3,approx=51)

# h-mode depths
depth.hM(A,B)
depth.hM(A,B,norm="L2")

# adjusted band depths
depth.ABD(A,B)
depth.ABD(A,B,norm="L2")

# band depth
depth.BD(A,B)

# half-region depth
depth.HR(A,B)

# random projection depth
depth.RP1(A,B)

m = 31
n = 21
d = 51

A2 = array(rnorm(m*d*2),dim=c(m,d,2))
B2 = array(rnorm(n*d*2),dim=c(n,d,2)) 

# integrated and infimal depths for bivariate functions
depth.fd2(A2,B2)

# h-mode depth for bivariate functions
depth.hM2(A2,B2)

# double random projection depth
depth.RP2(A2,B2)

# estimation of derivatives of a set of functions
AD = derivatives.est(A,deriv=c(0,1))
BD = derivatives.est(B,deriv=c(0,1))

# depth for functions including derivatives
depth.fd2(AD,BD)
depth.hM2(AD,BD)

# diagnostic plots for a function
A1 = as.matrix(population[1,1:61])
shape.fd.analysis(A1,B,order=1)
shape.fd.analysis(A1,B,order=2,approx=0)

# outlier detection
shape.fd.outliers(A)
}
