% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/depth.fd.R
\name{depth.fd1}
\alias{depth.fd1}
\title{Univariate integrated and infimal depth for functional data}
\usage{
depth.fd1(A, B, order = 1, approx = 0)
}
\arguments{
\item{A}{Functions whose depth is computed, represented by a matrix of its functional values of 
size \code{m*d}. \code{m} stands for the number of functions, \code{d}
is the number equidistant points in the domain of the data at which the functional
values of the \code{m} functions are evaluated.}

\item{B}{Random sample functions with respect to which the depth of \code{A} is computed. 
\code{B} is represented by a matrix of
size \code{n*d}, where \code{n} is the sample size, and \code{d}
is the number equidistant points in the domain of the data at which the functional
values of the \code{n} functions are evaluated. The grid of observation points for the 
functions \code{A} and \code{B} must be the same.}

\item{order}{The order of the order extended integrated and infimal depths.
By default, this is set to \code{1}, meaning that the usual univariate depths of 
the functional values are computed. For \code{order=2} or \code{3}, the second
and the third order extended integrated and infimal depths are computed, 
respectively.}

\item{approx}{Number of approximations used in the computation of the order extended depth
for \code{order} greater than \code{1}. For \code{order=2}, the default
value is set to \code{0}, meaning that the depth is computed at all possible \code{d^order}
combinations of the points in the domain. For \code{order=3}, 
the default value is set to \code{101}. When \code{approx} is a positive integer, \code{approx}
points are randomly sampled in \code{[0,1]^order} and at these points the \code{order}-variate depths of the
corresponding functional values are computed.}
}
\value{
Four vectors of length \code{m} of depth values are returned:
\itemize{
\item \code{Simpl_FD} the integrated depth based on the simplicial depth,
\item \code{Half_FD} the integrated depth based on the halfspace depth,
\item \code{Simpl_ID} the infimal depth based on the simplicial depth,
\item \code{Half_ID} the infimal depth based on the halfspace depth.
}
In addition, two vectors of length \code{m} of the relative area of smallest depth values is returned:
\itemize{
\item \code{Simpl_IA} the proportions of points at which the depth \code{Simpl_ID} was attained,
\item \code{Half_IA} the proportions of points at which the depth \code{Half_ID} was attained.
}
The values \code{Simpl_IA} and \code{Half_IA} are always in the interval [0,1]. 
They introduce ranking also among functions having the same
infimal depth value - if two functions have the same infimal depth, the one with larger infimal area
\code{IA} is said to be less central. 	
For \code{order=2} and \code{m=1}, two additional matrices of pointwise depths are also returned:
\itemize{
   \item \code{PSD} the matrix of size \code{d*d} containing the computed 
   pointwise bivariate simplicial depths used for the computation of \code{Simpl_FD} and \code{Simpl_ID},
   \item \code{PHD} the matrix of size \code{d*d} containing the computed 
   pointwise bivariate halfspace depths used for the computation of \code{Half_FD} and \code{Half_ID}.
}
For \code{order=3}, only \code{Half_FD} and \code{Half_ID} are provided.
}
\description{
Usual, and order extended integrated and infimal depths for real-valued functional data based on the
halfspace and simplicial depth.
}
\details{
The function returns vectors of sample integrated and infimal depth values.
}
\examples{
data(population)
A = as.matrix(population[1:20,1:66])
B = as.matrix(population[21:50,1:66])
depth.fd1(A,B)
depth.fd1(A,B,order=2)
depth.fd1(A,B,order=3,approx=51)

}
\author{
Stanislav Nagy, \email{stanislav.nagy@kuleuven.be}
}
\references{
Nagy, S., Gijbels, I. and Hlubinka, D.  (2016), Depth-based recognition of shape outlying functions, \emph{Under review}.
}
\seealso{
\code{\link{depth.fd2}}, \code{\link{infimalRank}}
}
\keyword{data}
\keyword{depth,}
\keyword{functional}
\keyword{infimal}
\keyword{integrated}

