% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/depth.fd.R
\name{derivatives.est}
\alias{derivatives.est}
\title{Estimation of the first two derivatives for functional data}
\usage{
derivatives.est(X, spar = NULL, deriv = c(0, 1), range = c(0, 1))
}
\arguments{
\item{X}{Functions whose derivatives are computed, represented by a matrix of its functional values of
size \code{m*d}. \code{m} stands for the number of functions, \code{d}
is the number equidistant points in the domain of the data at which the functional
values of the \code{m} functions are evaluated.}

\item{spar}{If provided, this parameter is passed to the function \code{D1ss} from package \code{sfsmisc}
as the value of the smoothing spline parameter in order to numerically approximate
the derivatives of \code{X}.}

\item{deriv}{A vector composed of \code{0}, \code{1}, and \code{2} of the demanded 
functional values / derivatives of the functions in the rows of \code{X}.
\code{0} stands for the functional values, \code{1} for the first derivatives, 
\code{2} for the second derivatives.}

\item{range}{A vector of two elements containing the range of the domain of the functions.
By default the range is set to \code{c(0,1)}.}
}
\value{
An array of the functional values and / or the derivatives of \code{X}. Its dimension
is \code{m*d*nd}, where \code{m*d} is the dimension of \code{X},
and \code{nd} is the demanded number of derivatives at the output, i.e.
the length of the vector \code{deriv}.
}
\description{
Returns an array of the values of derivatives of functional data.
}
\details{
If the input \code{X} is a matrix of size \code{m*d}, 
the function returns an array of dimension \code{m*d*nd}, where 
in the third dimension of the array the estimated values of the derivatives of \code{X}
are given.
\code{nd} here stands for \code{1}, \code{2} or \code{3}, depending on how many derivatives of \code{X} are
requested computed. For the estimation, the function \code{D1ss} from the package
\code{sfsmisc} is utilized.
}
\examples{
data(population)
A = as.matrix(population[1:20,1:66])
B = as.matrix(population[21:50,1:66])
derivatives.est(A,deriv=c(0,1))
}
\author{
Stanislav Nagy, \email{stanislav.nagy@kuleuven.be}
}
\keyword{data}
\keyword{derivatives,}
\keyword{functional}
\keyword{kernel,}

